function E = f_notched_beam_stiffness(forces,displacements,width,height,notch_depth,notch_width,length_eff)

% Evaluation of the Young's modulus for notched beam from load displacementdiagram
% f_notched_beam_stiffness(forces,displacements,width,height,notch_depth,notch_width,length_eff)
%
% input: vector with forces from loading test (forces) [N]
%        vector with displacements from loading test (displacements) [m]
%        C/S width [m]
%        C/S height [m]
%        notch depth [m]
%        notch width [m]
%        span of the beam - length between supports (length_eff) [m]
%
% output: Young's modulus (E) [Pa]
%
% written by Venca 12/03/2012 


%% Input processing

k = (forces(10)-forces(1))/(displacements(10)-displacements(1));
I = (width*height^3)/12;

%% Calculation of reduction coefficient

a = notch_depth/height;
alpha = -2.3617*a^4 + 6.587*a^3 - 5.2356*a^2 + 0.0815*a + 0.9277;

b = notch_width/length_eff;
beta = 14.981*b^2 - 4.587*b + 1.1053;

%% Stiffness calculation

E = (k*length_eff^3)/(alpha*beta*48*I);

end